function f = lennard_jones(x_i,x_j)
% LENNARD_JONES Lennard-Jones force.
%    F = LENNARDS_JONES(X_I,X_J) returns the force vector F between
%    particles X_I and X_J, where X_I and X_J can have dimension 2 or 3. F
%    has the same dimension.

stretch = 200;

x_i = x_i * stretch;
x_j = x_j * stretch;

cutoff = 5; % Cut-off radius.
r = norm(x_i-x_j);
k1 = 1;
k2 = 1;
m = 4;
n = 2;

if (r > cutoff)
   f = zeros(size(x_i));
elseif (r < 1e-5)
   f = (k1/1e-5^m - k2/1e-5^n) * (x_i-x_j)/1e-5;
else
   f = (k1/r^m - k2/r^n) * (x_i-x_j)/r;
end

f = f * 0.2;

if (norm(f) > 8)
   f = f./norm(f)*8;
end